RgbdNode

Struct RgbdNode 

pub struct RgbdNode { /* private fields */ }

Implementations

Source

impl RgbdNode

pub fn as_node(&self) -> &Node

View this node as a generic erased pipeline node.

Source

impl RgbdNode

pub fn inColor(&self) -> Result<Input>

pub fn inDepth(&self) -> Result<Input>

pub fn out(&self) -> Result<Output>

Source

impl RgbdNode

pub fn build(&self) -> Result<()>

pub fn build_ex( &self, autocreate: bool, mode: PresetMode, size: (i32, i32), fps: Option<f32>, ) -> Result<()>

Build the RGBD node with explicit configuration.

This maps to the native overload: dai::node::RGBD::build(autocreate, mode, size, fps).

Some devices/firmwares produce depth frames at sizes that don’t match the requested RGB frames. Using this builder allows the host node to be configured with the expected size (and optionally FPS), preventing runtime “Color and depth frame sizes do not match” errors.

pub fn set_depth_unit(&self, unit: DepthUnit)